==> otobo-10.0.20.tar.gz: otobo-10.0.20/AUTHORS.md <==
The following persons contributed to OTOBO:

* Johnny Hioe <jh@rother-oss.com>
* Grit Rother <mr@rother-oss.com>
* Daniel Dorna <dd@otrs.ch>
* Sven Oesterling <svo@rother-oss.com>
* Stefan Rother <sr@rother-oss.com>
* Stefan Abel <sta@rother-oss.com>
* Bernhard Schmalhofer <bernhard.schmalhofer@gmx.de>
* Khalil Hamada <khh@rother-oss.com>
* Stefan Härter <sha@rother-oss.com>
* OTOBO Team <https://rother-oss.com>
* San Miguel Team
* Yuri Myasoedov <ymyasoedov@yandex.ru> (Thanks for add RedisCache implementation)
* Renée Bäcker <info@perl-services.de>
* Fredy Aragón <fredmac48@hotmail.com>
* José Junior <jjunior@serviceup.com.br>
* Paul Yang <paul.yang@itservice.com.cn>
* Nicola Cordioli <cordioli.nicola@gmail.com>
* kess <kess-net@users.noreply.github.com>
* Kim Mølgaard <kim@itandmore.dk>
* dennis-dko <dk@rother-oss.com>
* Jens Pfeifer <jens.pfeifer@znuny.com>
* Helmut Wollmersdorfer <helmut@wollmersdorfer.at>
* Lars Dɪᴇᴄᴋᴏᴡ <lad@otobo.de>
* Philipp Kesler <philipp.kesler@hein.de>
* Przemysław Wilkosz <office@wilkosz.net>
* Intalio <intalio@intalio.pl>
* Kozo Sakurai <sakurai@io-architect.com>
* Yohann <yohann.duhamel@icloud.com>
* elpaso <eldaras20@gmail.com>
* Martin Gruner <martin.gruner@otrs.com>
* Tim Puettmanns <tim.puettmanns@maxence.de>
* Andreas Erhard <erhard@wor.net>
* David Krotil <david.krotil@hilo.cz>
* Emin Yazi <yazi@efflux.de>
* Frank Hildebrandt <frank@hildebrandt.io>
* Markus Hynnä <markus.hynna@mynamaki.fi>
* Yasen Arsov <jarsov@gmail.com>
* helabasa <R45XvezA@pm.me>
* Arkadiusz Dykiel <arkadiusz.dykiel@pep.pl>
* Charles Pigott <charlespigott@googlemail.com>
* FRamos <filipeparedesramos@gmail.com>
* Frank Wall <fw@moov.de>
* Gieanjalad <andy.fw88@gmail.com>
* Iago <icolomer@soligal.com>
* Irina Schaefer <irina.schaefer08@gmail.com>
* Jefferson Campos <foguinho.peruca@gmail.com>
* Jonas Plum <cugu@users.noreply.github.com>
* Kisuke <kisuke@kisuke.cz>
* LotharZok <111051858+LotharZok@users.noreply.github.com>
* Marco Ferrante <marco@csita.unige.it>
* Marcos Xavier Gil Júnior <marcosxaviergiljr@gmail.com>
* Massimo Composta <m.composta@e-time.it>
* Pau Nadeu Rabat <PAU.NADEU@networkhero.tech>
* Robert Grządka <otobo@sirocco.com.pl>
* Tomohisa Hirami <hirami@io-architect.com>
* Yuriy Purisev <duh.khv@gmail.com>
* sternenseemann <0rpkxez4ksa01gb3typccl0i@systemli.org>
* uid66 <19481514+uid66@users.noreply.github.com>

The following persons contributed to OTRS:

* 1soproni <csaba@sopron.hu>
* Alex Kantchev <ak@otrs.com>
* Alex Mazur <alex.mazur@otrs.com>
* Alexandre D. Rogoski <alexandre@exatati.com.br>
* André Brás <andre.bras@otrs.com>
* Balázs Úr <urbalazs@gmail.com>
* Belnet <info@belnet.be>
* Bernhard Schmalhofer <bernhard.schmalhofer@otrs.com>
* Bodo Bauer <bodo.bauer@otrs.com>
* Burchard Steinbild <burchard.steinbild@otrs.com>
* Carlos Garcia <carlos.garcia@otrs.com>
* Carlos Rodriguez <carlos.rodriguez@otrs.com>
* Christian Schöpplein <christian.schoepplein@otrs.com>
* Christopher T. Kuhn <christopher.kuhn@otrs.com>
* Cyrille Bollu <info@belnet.be>
* Daniel Zamorano <daniel.zamorano@otrs.com>
* David Crimi <deathpoison.dc@gmail.com>
* Denis Nelubin <dnelubin@gmail.com>
* Dennis Schmelter <dennis.schmelter@otrs.com>
* Diego Selzlein <diegoselzlein@gmail.com>
* Dietmar Berg <dietmar.berg@thalesgroup.com>
* Dominik Klein <dominik.klein@otrs.com>
* Dusan Vuckovic <dusan.vuckovic@otrs.com>
* Elias Probst <elias.probst@otrs.com>
* Elva Novoa <elva.novoa@otrs.com>
* Enrique Matías Sánchez (Quique) <cronopios@gmail.com>
* Felix Niklas <felix.niklas@otrs.com>
* Florian Liebe <florian.liebe@otrs.com>
* Friedrich Delgado <friedel@nomaden.org>
* Gerald Young <gerald.young@noynim.com>
* Henning Oschwald <henning.oschwald@otrs.com>
* IB Development Team <dev@ib.pl>
* Igor Djuric <igor.djuric@otrs.com>
* Jan Steinweg <jan.steinweg@otrs.com>
* Jaroslav Balaz <jaroslav.balaz@otrs.com>
* Jens Bothe <jens.bothe@otrs.com>
* Jens Pfeifer <jens.pfeifer@otrs.com>
* Johannes Hörburger <johannes.hoerburger@otrs.com>
* Johannes Nickel <hanne_hal@me.com>
* Keith Moore <tenareth@gmail.com>
* Luca Maranzano <liuk@linux.it>
* Manuel Hecht <manuel.hecht@otrs.com>
* Marc Bonsels <marc.bonsels@otrs.com>
* Marc Nilius <marc.nilius@otrs.com>
* Marco Buchholz <marco.buchholz@otrs.com>
* Marco Bucholz <marco.buchholz@otrs.com>
* Marco Ferrante <marco@csita.unige.it>
* Markus Esche <markus.esche@otrs.com>
* Martha Pascual <martha.pascual@otrs.com>
* Martin Edenhofer <martin.edenhofer@otrs.com>
* Martin Gross <martin@pc-coholic.de>
* Martin Gruner <martin.gruner@otrs.com>
* Mathias Bräunling <mathias.braeunling@otrs.com>
* Michael Tänzer <neo@nhng.de>
* Michiel Beijen <michiel.beijen@otrs.com>
* Milan Rakic <mrakic@s7designcreative.com>
* Moritz Lenz <mlenz@noris.net>
* NeverMin <never.min@gmail.com>
* Niels Dimmers <niels@nielsdimmers.nl>
* Nils Leideck <nils.leideck@leidex.net>
* Nils Leideck <nils.leideck@otrs.com>
* Norihiro Tanaka <noritnk@kcn.ne.jp>
* Oberson Dylan <dylan.oberson@epfl.ch>
* Oliver Tappe <oliver.tappe@otrs.com>
* Olivier Sallou <olivier.sallou@irisa.fr>
* Patrick Brischler <patrick.brischler@otrs.com>
* Patrick Rauscher <prauscher@ohai.su>
* Paul Waring <paul@xk7.net>
* Peter Krantz <peter@peterkrantz.se>
* Ralf Hildebrandt <hildeb@charite.de>
* Raphaël Doursenaud <rdoursenaud@gpcsolutions.fr>
* Renée Bäcker <info@perl-services.de>
* Richard Kammermayer <richard.kammermayer@otrs.com>
* Rolf Schmidt <rolf.schmidt@otrs.com>
* Romain THERRAT <romain42@gmail.com>
* Rui Patinha <rui.patinha@otrs.com>
* Sanjin Vik <svik@s7designcreative.com>
* Shawn Beasley <shawn.beasley@otrs.com>
* Stefan Bedorf <stefan.bedorf@otrs.com>
* Stefan Rother <stefan.rother@otrs.com>
* Stefan Wintermeyer <stefan@otrs.org>
* Theo van Hoesel <Th.J.v.Hoesel+GitHub@gmail.com>
* Thomas Raith <thomas.raith@otrs.com>
* Thomas Wouters <thomas@sijn.org>
* Thorsten Eckel <thorsten.eckel@otrs.com>
* Torsten Thau <Torsten.Thau@cape-it.de>
* Udo Bretz <udo.bretz@otrs.com>
* Uwe Dieckmann <uwe.dieckmann@otrs.com>
* Walter Souto <walter.souto@saude.go.gov.br>
* Wojciech Kuchta <klapi85@gmail.com>
* Wojciech Kuchta <wojciech.kuchta@allegro.pl>
* Zoran Ilibasic <zilibasic@s7designcreative.com>
* anonymous <uknown@anonymous>
* djurici <igor.djuric@muehlbauer.de>
* juanmclavero <juanm.clavero@ibsalut.es>
* otrsintern <otrsintern@gmail.com>
* s7design <otrs@s7designcreative.com>
* sergot <filip@sergot.pl>
* vlascoder <vlascoder@gmail.com>

==> otobo-10.1.5.tar.gz: otobo-10.1.5/AUTHORS.md <==
The following persons contributed to OTOBO:

* Johnny Hioe <jh@rother-oss.com>
* Grit Rother <mr@rother-oss.com>
* Daniel Dorna <dd@otrs.ch>
* Sven Oesterling <svo@rother-oss.com>
* Stefan Rother <sr@otrs.ch>
* San Miguel Team https://www.sanmiguel-brand-partner.com
* OTOBO Team <https://rother-oss.com>
* Yuri Myasoedov <ymyasoedov@yandex.ru> (Thanks for add RedisCache implementation)

The following persons contributed to OTRS:

* 1soproni <csaba@sopron.hu>
* Alex Kantchev <ak@otrs.com>
* Alex Mazur <alex.mazur@otrs.com>
* Alexandre D. Rogoski <alexandre@exatati.com.br>
* André Brás <andre.bras@otrs.com>
* Balázs Úr <urbalazs@gmail.com>
* Belnet <info@belnet.be>
* Bernhard Schmalhofer <bernhard.schmalhofer@otrs.com>
* Bodo Bauer <bodo.bauer@otrs.com>
* Burchard Steinbild <burchard.steinbild@otrs.com>
* Carlos Garcia <carlos.garcia@otrs.com>
* Carlos Rodriguez <carlos.rodriguez@otrs.com>
* Christian Schöpplein <christian.schoepplein@otrs.com>
* Christopher T. Kuhn <christopher.kuhn@otrs.com>
* Cyrille Bollu <info@belnet.be>
* Daniel Zamorano <daniel.zamorano@otrs.com>
* David Crimi <deathpoison.dc@gmail.com>
* Denis Nelubin <dnelubin@gmail.com>
* Dennis Schmelter <dennis.schmelter@otrs.com>
* Diego Selzlein <diegoselzlein@gmail.com>
* Dietmar Berg <dietmar.berg@thalesgroup.com>
* Dominik Klein <dominik.klein@otrs.com>
* Dusan Vuckovic <dusan.vuckovic@otrs.com>
* Elias Probst <elias.probst@otrs.com>
* Elva Novoa <elva.novoa@otrs.com>
* Enrique Matías Sánchez (Quique) <cronopios@gmail.com>
* Felix Niklas <felix.niklas@otrs.com>
* Florian Liebe <florian.liebe@otrs.com>
* Friedrich Delgado <friedel@nomaden.org>
* Gerald Young <gerald.young@noynim.com>
* Henning Oschwald <henning.oschwald@otrs.com>
* IB Development Team <dev@ib.pl>
* Igor Djuric <igor.djuric@otrs.com>
* Jan Steinweg <jan.steinweg@otrs.com>
* Jaroslav Balaz <jaroslav.balaz@otrs.com>
* Jens Bothe <jens.bothe@otrs.com>
* Jens Pfeifer <jens.pfeifer@otrs.com>
* Johannes Hörburger <johannes.hoerburger@otrs.com>
* Johannes Nickel <hanne_hal@me.com>
* Keith Moore <tenareth@gmail.com>
* Luca Maranzano <liuk@linux.it>
* Manuel Hecht <manuel.hecht@otrs.com>
* Marc Bonsels <marc.bonsels@otrs.com>
* Marc Nilius <marc.nilius@otrs.com>
* Marco Buchholz <marco.buchholz@otrs.com>
* Marco Bucholz <marco.buchholz@otrs.com>
* Marco Ferrante <marco@csita.unige.it>
* Markus Esche <markus.esche@otrs.com>
* Martha Pascual <martha.pascual@otrs.com>
* Martin Edenhofer <martin.edenhofer@otrs.com>
* Martin Gross <martin@pc-coholic.de>
* Martin Gruner <martin.gruner@otrs.com>
* Mathias Bräunling <mathias.braeunling@otrs.com>
* Michael Tänzer <neo@nhng.de>
* Michiel Beijen <michiel.beijen@otrs.com>
* Milan Rakic <mrakic@s7designcreative.com>
* Moritz Lenz <mlenz@noris.net>
* NeverMin <never.min@gmail.com>
* Niels Dimmers <niels@nielsdimmers.nl>
* Nils Leideck <nils.leideck@leidex.net>
* Nils Leideck <nils.leideck@otrs.com>
* Norihiro Tanaka <noritnk@kcn.ne.jp>
* Oberson Dylan <dylan.oberson@epfl.ch>
* Oliver Tappe <oliver.tappe@otrs.com>
* Olivier Sallou <olivier.sallou@irisa.fr>
* Patrick Brischler <patrick.brischler@otrs.com>
* Patrick Rauscher <prauscher@ohai.su>
* Paul Waring <paul@xk7.net>
* Peter Krantz <peter@peterkrantz.se>
* Ralf Hildebrandt <hildeb@charite.de>
* Raphaël Doursenaud <rdoursenaud@gpcsolutions.fr>
* Renée Bäcker <info@perl-services.de>
* Richard Kammermayer <richard.kammermayer@otrs.com>
* Rolf Schmidt <rolf.schmidt@otrs.com>
* Romain THERRAT <romain42@gmail.com>
* Rui Patinha <rui.patinha@otrs.com>
* Sanjin Vik <svik@s7designcreative.com>
* Shawn Beasley <shawn.beasley@otrs.com>
* Stefan Bedorf <stefan.bedorf@otrs.com>
* Stefan Rother <stefan.rother@otrs.com>
* Stefan Wintermeyer <stefan@otrs.org>
* Theo van Hoesel <Th.J.v.Hoesel+GitHub@gmail.com>
* Thomas Raith <thomas.raith@otrs.com>
* Thomas Wouters <thomas@sijn.org>
* Thorsten Eckel <thorsten.eckel@otrs.com>
* Torsten Thau <Torsten.Thau@cape-it.de>
* Udo Bretz <udo.bretz@otrs.com>
* Uwe Dieckmann <uwe.dieckmann@otrs.com>
* Walter Souto <walter.souto@saude.go.gov.br>
* Wojciech Kuchta <klapi85@gmail.com>
* Wojciech Kuchta <wojciech.kuchta@allegro.pl>
* Zoran Ilibasic <zilibasic@s7designcreative.com>
* anonymous <uknown@anonymous>
* djurici <igor.djuric@muehlbauer.de>
* juanmclavero <juanm.clavero@ibsalut.es>
* otrsintern <otrsintern@gmail.com>
* s7design <otrs@s7designcreative.com>
* sergot <filip@sergot.pl>
* vlascoder <vlascoder@gmail.com>
